Welcome to NABQR's documentation!
======================================


.. toctree::
   :maxdepth: 3
   :caption: Contents:


   readme
   installation
   usage
   modules
   contributing
   authors
   history




Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
